==> jboss-4.0.2.zip: testsuite/src/main/org/jboss/test/classloader/test/ClasspathExtensionUnitTestCase.java <==
/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.test.classloader.test;

import javax.management.Attribute;
import javax.management.ObjectName;

import junit.framework.Test;

import org.jboss.test.JBossTestCase;
import org.jboss.test.JBossTestServices;
import org.jboss.test.JBossTestSetup;

/**
 * Unit tests for the org.jboss.deployment.ClasspathExtension
 * @author Scott.Stark@jboss.org
 * @version $Revision:1$
 */
public class ClasspathExtensionUnitTestCase extends JBossTestCase
{
   ObjectName extension;

   public ClasspathExtensionUnitTestCase(String name)
   {
      super(name);

      try
      {
         extension = new ObjectName("jboss.test:test=ClasspathTest,mbean=extension");
      }
      catch (Exception ignored)
      {
      }
   }

   public void testClasspathExtension() throws Exception
   {
      assertTrue("Shouldn't find the resource before deployment", findResource() == false);
      getServer().createMBean("org.jboss.deployment.ClasspathExtension", extension);
      try
      {
         getServer().setAttribute(extension, new Attribute("MetadataURL", getDeployURL("")));
         getServer().invoke(extension, "create", new Object[0], new String[0]);
         getServer().invoke(extension, "start", new Object[0], new String[0]);
         assertTrue("Should find the resource after deployment", findResource());
      }
      finally
      {
         getServer().invoke(extension, "stop", new Object[0], new String[0]);
         getServer().invoke(extension, "destroy", new Object[0], new String[0]);
         getServer().unregisterMBean(extension);
      }
      assertTrue("Shouldn't find the resource after undeployment", findResource() == false);
   }

   private boolean findResource()
      throws Exception
   {
      return ((Boolean) getServer().invoke(new ObjectName("jboss.test:test=ClasspathTest"), "findResource",
         new Object[] { "classpath.sar" }, new String[] { String.class.getName() })).booleanValue();
   }

   public static Test suite() throws Exception
   {
      return new JBossTestSetup(getDeploySetup(ClasspathExtensionUnitTestCase.class, "classpath.sar"));
   }
}

==> jboss-4.0.4.zip: testsuite/src/main/org/jboss/test/classloader/test/ClasspathExtensionUnitTestCase.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.classloader.test;

import javax.management.Attribute;
import javax.management.ObjectName;

import junit.framework.Test;

import org.jboss.test.JBossTestCase;
import org.jboss.test.JBossTestSetup;

/**
 * Unit tests for the org.jboss.deployment.ClasspathExtension
 * @author Scott.Stark@jboss.org
 * @version $Revision$
 */
public class ClasspathExtensionUnitTestCase extends JBossTestCase
{
   ObjectName extension;

   public ClasspathExtensionUnitTestCase(String name)
   {
      super(name);

      try
      {
         extension = new ObjectName("jboss.test:test=ClasspathTest,mbean=extension");
      }
      catch (Exception ignored)
      {
      }
   }

   public void testClasspathExtension() throws Exception
   {
      assertTrue("Shouldn't find the resource before deployment", findResource() == false);
      getServer().createMBean("org.jboss.deployment.ClasspathExtension", extension);
      try
      {
         getServer().setAttribute(extension, new Attribute("MetadataURL", getDeployURL("").toString()));
         getServer().invoke(extension, "create", new Object[0], new String[0]);
         getServer().invoke(extension, "start", new Object[0], new String[0]);
         assertTrue("Should find the resource after deployment", findResource());
      }
      finally
      {
         getServer().invoke(extension, "stop", new Object[0], new String[0]);
         getServer().invoke(extension, "destroy", new Object[0], new String[0]);
         getServer().unregisterMBean(extension);
      }
      assertTrue("Shouldn't find the resource after undeployment", findResource() == false);
   }

   private boolean findResource()
      throws Exception
   {
      return ((Boolean) getServer().invoke(new ObjectName("jboss.test:test=ClasspathTest"), "findResource",
         new Object[] { "classpath.sar" }, new String[] { String.class.getName() })).booleanValue();
   }

   public static Test suite() throws Exception
   {
      return new JBossTestSetup(getDeploySetup(ClasspathExtensionUnitTestCase.class, "classpath.sar"));
   }
}
